@@ -7,41 +7,42 @@
 #### ----------------------- Declaring new classes
 #### ----------------------- This class is a link between cluster and job management
 
-#' @title queue defines the class
+#' @rdname queue
+#' 
 #' @exportClass queue
 setClass("queue", representation(submit_exe = "character", ## submit job
-	queue = "character", ## type of queue
-	jobname = "character", ## name of a job, in the batch queue
-	nodes = "character", ## number of nodes, or name of the node
-	cpu = "numeric",   ## number of cpus
-	memory = "character", ## memory to be reserved
-	dependency = "list", ## job id
-	walltime = "character", ## walltime
-	cwd = "character", ## home
-	stderr = "character", ## stderr
-	stdout = "character",
-	email = "character", ## email
-	platform = "character",  ## torque etc
-	format = "character", ## cmd format
-	extra_opts= "character", ## extra options for your queue
-	server = "character")) ## address of head node
+																 queue = "character", ## type of queue
+																 jobname = "character", ## name of a job, in the batch queue
+																 nodes = "character", ## number of nodes, or name of the node
+																 cpu = "numeric",   ## number of cpus
+																 memory = "character", ## memory to be reserved
+																 dependency = "list", ## job id
+																 walltime = "character", ## walltime
+																 cwd = "character", ## home
+																 stderr = "character", ## stderr
+																 stdout = "character",
+																 email = "character", ## email
+																 platform = "character",  ## torque etc
+																 format = "character", ## cmd format
+																 extra_opts= "character", ## extra options for your queue
+																 server = "character")) ## address of head node
 
 
 #### ----------------------- represents a single job
 setClass("job", representation(cmds = "character",
-	name = "character",## for creating stdout etc
-	base_path = "character",
-	id = "character", ## can be multiple
-	uid = "character",
-	status = "character", ## status
-	exit_code = "numeric", ## status
-	submission_type = "character", ## scatter, serial
-	dependency_type = "character", ## gather, serial
-	previous_job = "character",
-	script = "character", ## the final script which has been used (if multiple cmds the last one)
-	trigger = "character",
-	next_job = "character"),
-	contains = "queue") ## a string of cmd to run
+															 name = "character",## for creating stdout etc
+															 base_path = "character",
+															 id = "character", ## can be multiple
+															 uid = "character",
+															 status = "character", ## status
+															 exit_code = "numeric", ## status
+															 submission_type = "character", ## scatter, serial
+															 dependency_type = "character", ## gather, serial
+															 previous_job = "character",
+															 script = "character", ## the final script which has been used (if multiple cmds the last one)
+															 trigger = "character",
+															 next_job = "character"),
+				 contains = "queue") ## a string of cmd to run
 
 setClass("local", contains = "job")
 setClass("torque", contains = "job")
@@ -52,24 +53,27 @@ setClass("moab", contains = "job")
 setClass("slurm", contains = "job")
 
 
-#' flow defines the class
+#' @rdname flow
+#' 
 #' @exportClass flow
 setClass("flow", representation(jobs = "list",
-	flow_run_path = "character",
-	flow_path = "character",
-	trigger_path = "character",
-	desc = "character",
-	status = "character", ## status
-	mode = "character", ## what kind of flow this is
-	name = "character",
-	version = "character",
-	execute = "logical"))
+																flow_run_path = "character",
+																flow_path = "character",
+																trigger_path = "character",
+																desc = "character",
+																status = "character", ## status
+																mode = "character", ## what kind of flow this is
+																name = "character",
+																version = "character",
+																execute = "logical"))
 
-#### ---------------------- Functions to create new classes
-#' Create a \code{queue} object which containg details about how a job is submitted.
+
+#' @rdname queue
+#' 
+#' @title A \code{queue} object defines details regarding how a job is submitted
 #'
-#' This function defines the queue used to submit jobs to the cluster. In essence details about the
-#' computing cluster in use.
+#' @description 
+#' Internal function (used by \link{to_flow}), to define the format used to submit a job.
 #'
 #' @param object this is not used currenlty, ignore.
 #' @param platform Required and important. Currently supported values are 'lsf' and 'torque'. [Used by class job]
@@ -92,77 +96,87 @@ setClass("flow", representation(jobs = "list",
 #'
 #'
 #' @details
-#' ## Resources:
+#' \strong{Resources}:
 #' Can be defined **once** using a \link{queue} object and recylced to all the jobs in a flow. If resources (like memory, cpu, walltime, queue) are supplied at the
 #' job level they overwrite the one supplied in \link{queue}
 #' Nodes: can be supplied ot extend a job across multiple nodes. This is purely experimental and not supported.
-#' ## Server:
+#' 
+#' \strong{Server}:
 #' This a hook which may be implemented in future.
-#' ## Submission script:
+#' 
+#' \strong{Submission script}
 #' The 'platform' variable defines the format, and submit_exe; however these two are avaible for someone to create a custom submission command.
+#' 
 #' @inheritParams job
+#' 
 #' @keywords queue
+#' 
 #' @export
+#' 
 #' @examples
 #' qobj <- queue(platform='lsf')
 queue <- function(object,
-	platform = c('local', 'lsf', 'torque', 'sge', 'moab'),
-	## --- format is a advanced option, use with caution
-	format = "",
-	## --- Following are replaced by job()
-	queue = "long",
-	walltime, memory, cpu = 1,
-	## format
-	extra_opts = "",
-	submit_exe,
-	nodes = '1',  ## only used in torque
-	## debug use
-	jobname = "name",
-	email = Sys.getenv("USER"),
-	dependency = list(),
-	server = "localhost",
-	verbose = FALSE,
-	cwd = "",
-	stderr = "",
-	stdout = "",
-	...){
+									platform = c('local', 'lsf', 'torque', 'sge', 'moab'),
+									## --- format is a advanced option, use with caution
+									format = "",
+									## --- Following are replaced by job()
+									queue = "long",
+									walltime, memory, cpu = 1,
+									## format
+									extra_opts = "",
+									submit_exe,
+									nodes = '1',  ## only used in torque
+									## debug use
+									jobname = "name",
+									email = Sys.getenv("USER"),
+									dependency = list(),
+									server = "localhost",
+									verbose = FALSE,
+									cwd = "",
+									stderr = "",
+									stdout = "",
+									...){
 	platform = match.arg(platform)
 	if (!missing(object)){
 		object = replace_slots(object = object, ...)
 		return(object)
 	}
-
+	
 	## --- setting defaults
 	if (missing(walltime)){
 		walltime = switch(platform,
-			torque = "72:00:00",
-			lsf = "72:00",
-			"24:00")
+											torque = "72:00:00",
+											lsf = "72:00",
+											"24:00")
 		if (verbose)
 			message("Setting default time to: ", walltime,
-				". If this is more than queue max (/improper format), job will fail. You may change this in job()\n")
+							". If this is more than queue max (/improper format), job will fail. You may change this in job()\n")
 	}
 	if (missing(memory)){
 		memory = switch(platform,
-			lsf = "10000",
-			torque = "10g",
-			"1000")
+										lsf = "10000",
+										torque = "10g",
+										"1000")
 		if (verbose)
 			message("Setting default memory to: ", memory,
-				". If this is more than queue max (/improper format), job will fail.\n")
+							". If this is more than queue max (/improper format), job will fail.\n")
 	}
 	if (platform %in% c("torque", "sge")){
+		
 		if (missing(format))
 			format="${SUBMIT_EXE} -N ${JOBNAME} -q ${QUEUE} -l nodes=${NODES}:ppn=${CPU} -l walltime=${WALLTIME} -l mem=${MEMORY} -S /bin/bash -d ${CWD} -V -o ${STDOUT} -m ae -M ${EMAIL} -j oe -r y -V ${EXTRA_OPTS} ${CMD} ${DEPENDENCY}"
-		object <- new("torque", submit_exe="qsub", queue=queue,
-			nodes=nodes,cpu=cpu,jobname=jobname,
-			dependency=dependency,walltime=walltime,
-			cwd=cwd, #stderr=stderr,
-			memory=memory,
-			stdout=stdout,email = email,platform=platform,
-			#format=format,
-			extra_opts = extra_opts,
-			server=server)
+		if(missing(submit_exe))
+			submit_exe = "qsub"
+		
+		object <- new("torque", submit_exe=submit_exe, queue=queue,
+									nodes=nodes,cpu=cpu,jobname=jobname,
+									dependency=dependency,walltime=walltime,
+									cwd=cwd, #stderr=stderr,
+									memory=memory,
+									stdout=stdout,email = email,platform=platform,
+									#format=format,
+									extra_opts = extra_opts,
+									server=server)
 	}else if (platform=="lsf"){
 		## restrict cores to one node
 		## bsub -q myqueue -J myjob -o myout -e myout -n cpu -cwd mywd -m mem -W 02:00 < script.sh
@@ -172,41 +186,49 @@ queue <- function(object,
 		## -R rusage[mem=16385]: min mem (reserved mem)
 		if (missing(format))
 			format="${SUBMIT_EXE} -q ${QUEUE} -J ${JOBNAME} -o ${STDOUT} -e ${STDERR} -n ${CPU} -cwd ${CWD} -M ${MEMORY} -R rusage[mem=${MEMORY}] -R span[ptile=${CPU}] -W ${WALLTIME} -r ${EXTRA_OPTS} ${DEPENDENCY} '<' ${CMD} " ## rerun failed jobs
-		object <- new("lsf", submit_exe="bsub",queue=queue,
-			nodes=nodes, cpu=cpu, jobname=jobname,
-			dependency=dependency, walltime=walltime,
-			memory=memory,
-			cwd=cwd, stderr=stderr,
-			stdout=stdout, email=email,platform=platform,
-			#format=format,
-			extra_opts = extra_opts,
-			server=server)
+		if(missing(submit_exe))
+			submit_exe = "bsub"
+		
+		object <- new("lsf", submit_exe=submit_exe,queue=queue,
+									nodes=nodes, cpu=cpu, jobname=jobname,
+									dependency=dependency, walltime=walltime,
+									memory=memory,
+									cwd=cwd, stderr=stderr,
+									stdout=stdout, email=email,platform=platform,
+									#format=format,
+									extra_opts = extra_opts,
+									server=server)
 	}else if (platform=="local"){
-		object <- new("local", submit_exe='bash',queue=queue,
-			nodes=nodes, memory=memory,
-			cpu=cpu,dependency=dependency,walltime=walltime,
-			cwd=cwd,stderr=stderr,stdout=stdout,email=email,platform=platform, extra_opts = extra_opts,
-			jobname=jobname,#format=format,
-			server=server)
+		if(missing(submit_exe))
+			submit_exe = "bash"
+		
+		object <- new("local", submit_exe=submit_exe,queue=queue,
+									nodes=nodes, memory=memory,
+									cpu=cpu,dependency=dependency,walltime=walltime,
+									cwd=cwd,stderr=stderr,stdout=stdout,email=email,platform=platform, extra_opts = extra_opts,
+									jobname=jobname,#format=format,
+									server=server)
 	}else if (platform %in% c("moab")){
 		if (missing(format))
 			format="${SUBMIT_EXE} -N ${JOBNAME} -l nodes=${NODES}:ppn=${CPU} -l walltime=${WALLTIME} -l mem=${MEMORY} -S /bin/bash -d ${CWD} -V -o ${STDOUT} -m ae -M ${EMAIL} -j oe -r y -V ${EXTRA_OPTS} ${CMD} ${DEPENDENCY}"
-		object <- new("moab", submit_exe="msub", queue=queue,
-			nodes=nodes,cpu=cpu,jobname=jobname,
-			dependency=dependency,walltime=walltime,
-			cwd=cwd,#stderr=stderr,
-			memory=memory,
-			stdout=stdout,email = email,platform=platform,
-			extra_opts = extra_opts,
-			server=server)
-
+		if(missing(submit_exe))
+			submit_exe = "msub"
+		object <- new("moab", submit_exe=submit_exe, queue=queue,
+									nodes=nodes,cpu=cpu,jobname=jobname,
+									dependency=dependency,walltime=walltime,
+									cwd=cwd,#stderr=stderr,
+									memory=memory,
+									stdout=stdout,email = email,platform=platform,
+									extra_opts = extra_opts,
+									server=server)
+		
 	}else{
 		object <- new('queue', submit_exe=submit_exe,
-			queue=queue,
-			nodes=nodes, memory=memory,
-			cpu=cpu,dependency=dependency,walltime=walltime,
-			cwd=cwd,stderr=stderr,stdout=stdout,email=email,platform=platform, extra_opts = extra_opts,
-			jobname=jobname,server=server)
+									queue=queue,
+									nodes=nodes, memory=memory,
+									cpu=cpu,dependency=dependency,walltime=walltime,
+									cwd=cwd,stderr=stderr,stdout=stdout,email=email,platform=platform, extra_opts = extra_opts,
+									jobname=jobname,server=server)
 	}
 	return(object)
 }
@@ -214,7 +236,9 @@ queue <- function(object,
 ## submission_type: this decides that the cmds to be submittion in which manner
 ## flow_type: if multi dependencies, wait for all or according to order
 
-#' job class
+#' Describing details of the job object
+#' 
+#' Internal function (used by to_flow), which aids in creating a job object.
 #'
 #' @param cmds the commands to run
 #' @param name name of the job
@@ -257,14 +281,14 @@ queue <- function(object,
 #'
 #' }
 job <- function(cmds = "",
-	name = "myjob",
-	q_obj = new("queue"),
-	previous_job = '',
-	cpu = 1,
-	memory, walltime,
-	submission_type = c("scatter", "serial"),
-	dependency_type = c("none", "gather", "serial", "burst"),
-	...){
+								name = "myjob",
+								q_obj = new("queue"),
+								previous_job = '',
+								cpu = 1,
+								memory, walltime,
+								submission_type = c("scatter", "serial"),
+								dependency_type = c("none", "gather", "serial", "burst"),
+								...){
 	#message(name)
 	## convert to numeric if possible
 	cpu <- as.numeric(cpu)
@@ -284,34 +308,31 @@ job <- function(cmds = "",
 	if (prevjob_exists(previous_job) & dependency_type == 'none')
 		stop("Previous job specified, but you have not specified dependency_type")
 	object <- new(q_obj@platform,
-		cmds = cmds,
-		object,
-		name = name,
-		submission_type = submission_type,
-		previous_job = previous_job,
-		status = "",
-		dependency_type = dependency_type,...)
+								cmds = cmds,
+								object,
+								name = name,
+								submission_type = submission_type,
+								previous_job = previous_job,
+								status = "",
+								dependency_type = dependency_type,...)
 	return(object)
 }
 
-#' Flow constructor
-#' @param jobs \code{list} A list of jobs to be included in this flow
-#' @param name \code{character} Name of the flow. Defaults to \code{'newname'}
-#' Used in \link{submit_flow} to name the working directories.
-#' @param desc \code{character} Description of the flow
-#' This is used to name folders (when submitting jobs, see \link{submit_flow}).
-#' It is good practice to avoid spaces and other special characters.
-#' An underscore '_' seems like a good word separator.
-#' Defaults to 'my_super_flow'. We usually use this to put sample names of the data.
-#' @param mode \code{character} Mode of submission of the flow.
-#' @param flow_run_path The base path of all the flows you would submit.
-#' Defaults to \code{~/flows}. Best practice to ignore it.
-#' @param trigger_path \code{character}
-#' Defaults to \code{~/flows/trigger}. Best practice to ignore it.
-#' @param flow_path \code{character}
-#' @param status \code{character} Not used at this time
+#' Describing the flow class
+#' 
+#' Internal function (used by \link{to_flow}), which aids in creating a flow object.
+#' 
+#' @param jobs \code{list}: A list of jobs to be included in this flow
+#' @param name \code{character}: Name of the flow. ['newflow']
+#' @param desc \code{character} Description of the flow, used to uniquely identify a 
+#' flow instance. ['my_super_flow']
+#' @param mode \code{character} Mode of submission of the flow (depreciated). ['scheduler']
+#' @param flow_run_path The base path of all the flows you would submit. [~/flows]
+#' @param trigger_path \code{character} [\code{~/flows/trigger}].
+#' @param flow_path \code{character}: A unique path identifying a flow instance, populated by \link{submit_flow}.
+#' @param status \code{character}: Status of the flow.
 #' @param version version of flowr used to create and execute this flow.
-#' @param execute executtion status of flow object.
+#' @param execute executtion status of flow object. [FALSE]
 #' @export
 #' @examples
 #' cmds = rep("sleep 5", 10)
@@ -349,7 +370,7 @@ flow <- function(
 	trigger_path = "",
 	flow_path = "",
 	version = '0.0',
-	status="",
+	status="created",
 	execute = ""){
 	mode <- match.arg(mode)
 	## create a list of jobs if nore already
@@ -357,23 +378,25 @@ flow <- function(
 	jobnames <-  sapply(jobs, slot, "name")
 	names(jobs) = jobnames
 	object <- new("flow", jobs=jobs,
-		mode = mode,
-		name = name, flow_run_path = flow_run_path,
-		trigger_path = trigger_path,
-		flow_path=flow_path,
-		desc=desc,
-		version = version,
-		status=status)
+								mode = mode,
+								name = name, flow_run_path = flow_run_path,
+								trigger_path = trigger_path,
+								flow_path=flow_path,
+								desc=desc,
+								version = version,
+								status=status)
 	return(object)
 }
 
-if (FALSE){
 
+
+if (FALSE){
+	
 	#q.obj <- queue(platform="torque")
 	q2 <- queue(object=qobj,cpu=5)
-
+	
 	replace_slots(q.obj,cpu=4,name="newname")
-
+	
 	## class(q)
 	## test_queue(q, verbose=TRUE)
 	## hpcc.command.format <- "#{CMD} | qsub -N #{NAME} -q #{QUEUE} -l #{NODES}:#{PPN} -l #{WALLTIME} -S /bin/bash -d #{HOME} -V -e #{STDERR} -o #{STDERR} -m ae -M #{EMAIL}"
@@ -383,23 +406,23 @@ if (FALSE){
 	q_obj <- queue(platform="torque")
 	cpu_aln=1
 	jobj <- job(q_obj=q_obj,cmd="sleep 2",cpu=cpu_aln)
-
+	
 	jobj@base_path <- "~/tmp/flows"
 	#trace(create_queue_cmd, browser, signature="queue")
 	#debug(slots_as_list)
 	jobj <- submit_job(jobj, execute = TRUE, verbose = TRUE,
-		wd="~/tmp/flows/test_2481e475-31a0-41fc-8b01-cf01272abc3a")
-
+										 wd="~/tmp/flows/test_2481e475-31a0-41fc-8b01-cf01272abc3a")
+	
 	j.obj <- job(queue=q.obj,cmd="sleep 2")
-
+	
 	## flow name: align_merge
 	## job use bowtie on two of them
 	## merge them using picard
-
+	
 	f.align <- (name="align_merge")
 	align.cmds <- sprintf("echo 'aligning using bowtie';sleep %s",
-		round(runif (10)*10,2))
-
-
+												round(runif (10)*10,2))
+	
+	
 }
 
